@@ -26,7 +26,7 @@ if(multiple){
 cat("  Dependent Variable: Cmax_ss                       \n")
 cat("\n")
 cat("Type I SS\n")
-Cmax_ss<- lm(log(Cmax_ss) ~ seq + subj + prd + drug , data=Data)
+Cmax_ss<- lm(log(Cmax_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(Cmax_ss)
 show(BearAnova)
 cat("\n")
@@ -42,13 +42,13 @@ print(summary(aov(Cmax_ss ~ prd*drug + Error(subj) , data=Data)))
 ### the data for multiple-dose was ported from TotalData with the same data column; Cmax of single-dose is
 ### replaced by Cmax_ss in the case of multiple-dose.
 ###
-Cmax<- lm(Cmax ~ seq + subj + prd + drug , data=TotalData)
+Cmax<- lm(Cmax ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
 cat("  Dependent Variable: Cmax                       \n")
 cat("\n")
 cat("Type I SS\n")
-Cmax<- lm(Cmax ~ seq + subj + prd + drug, data=TotalData)
+Cmax<- lm(Cmax ~ seq + subj:seq + prd + drug, data=TotalData)
 BearAnova=anova(Cmax)
 show(BearAnova)
 cat("\n")
@@ -69,7 +69,7 @@ if(multiple){
 cat("  Dependent Variable: AUC(tau)ss                 \n")
 cat("\n")
 cat("Type I SS\n")
-AUCtau_ss<- lm(AUCtau_ss ~ seq + subj+ prd + drug , data=Data)
+AUCtau_ss<- lm(AUCtau_ss ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(AUCtau_ss)
 show(BearAnova)
 cat("\n")
@@ -79,13 +79,13 @@ show(AUCtau_ss_drop1)
 cat("\n")
 cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
 print(summary(aov(AUCtau_ss ~ prd*drug + Error(subj) , data=Data)))
-AUC0t<- lm(AUC0t ~ seq + subj + prd + drug , data=TotalData)
+AUC0t<- lm(AUC0t ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
 cat("  Dependent Variable: AUC0t                      \n")
 cat("\n")
 cat("Type I SS\n")
-AUC0t<- lm(AUC0t ~ seq + subj + prd + drug , data=TotalData)
+AUC0t<- lm(AUC0t ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(AUC0t)
 show(BearAnova)
 cat("\n")
@@ -108,7 +108,7 @@ cat("-----------------------------------------------\n")
 cat("  Dependent Variable: AUC0INF                  \n")
 cat("\n")
 cat("Type I SS\n")
-AUC0INF<- lm(AUC0INF ~ seq + subj + prd + drug , data=TotalData)
+AUC0INF<- lm(AUC0INF ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(AUC0INF)
 show(BearAnova)
 cat("\n")
@@ -129,7 +129,7 @@ if(multiple){
 cat("  Dependent Variable: log(Cmax_ss)    \n")
 cat("\n")
 cat("Type I SS\n")
-lnCmax_ss<- lm(log(Cmax_ss) ~ seq + subj + prd + drug , data=Data)
+lnCmax_ss<- lm(log(Cmax_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(lnCmax_ss)
 show(BearAnova)
 cat("\n")
@@ -142,12 +142,12 @@ cat("      balanced crossover study.\n")
 cat("\n")
 cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
 print(summary(aov(log(Cmax_ss) ~ prd*drug + Error(subj) , data=Data)))
-lnCmax<- lm(log(Cmax) ~ seq + subj + prd + drug , data=TotalData)
+lnCmax<- lm(log(Cmax) ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
 cat("  Dependent Variable: log(Cmax)                           \n")
-lnCmax<- lm(log(Cmax)~ seq + subj + prd + drug, data=TotalData)
-### lnCmax<- aov(log(Cmax) ~ seq + subj + prd + drug, data=TotalData)
+lnCmax<- lm(log(Cmax)~ seq + subj:seq + prd + drug, data=TotalData)
+### lnCmax<- aov(log(Cmax) ~ seq + subj:seq + prd + drug, data=TotalData)
 ### print(summary(lnCmax))
 cat("\n")
 cat("ANOVA Table incl. Type I SS\n")
@@ -191,7 +191,7 @@ if(multiple){
 cat("  Dependent Variable: log(AUCtau_ss) \n")
 cat("\n")
 cat("Type I SS\n")
-lnAUCtau_ss<- lm(log(AUCtau_ss) ~ seq + subj + prd + drug , data=Data)
+lnAUCtau_ss<- lm(log(AUCtau_ss) ~ seq + subj:seq + prd + drug , data=Data)
 BearAnova=anova(lnAUCtau_ss)
 show(BearAnova)
 cat("\n")
@@ -201,13 +201,13 @@ show(lnAUCtau_ss_drop1)
 cat("\n")
 cat("Tests of Hypothesis for SUBJECT(SEQUENCE) as an error term\n")
 print(summary(aov(log(AUCtau_ss) ~ prd*drug + Error(subj) , data=Data)))
-lnAUC0t<- lm(log(AUC0t) ~ seq + subj + prd + drug , data=TotalData)
+lnAUC0t<- lm(log(AUC0t) ~ seq + subj:seq + prd + drug , data=TotalData)
 }
 else{
 cat("  Dependent Variable: log(AUC0t)     \n")
 cat("\n")
 cat("Type I SS\n")
-lnAUC0t<- lm(log(AUC0t) ~ seq + subj + prd + drug , data=TotalData)
+lnAUC0t<- lm(log(AUC0t) ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(lnAUC0t)
 show(BearAnova)
 cat("\n")
@@ -243,7 +243,7 @@ cat("--------------------------------------\n")
 cat("  Dependent Variable: log(AUC0INF)    \n")
 cat("\n")
 cat("Type I SS\n")
-lnAUC0INF<- lm(log(AUC0INF) ~ seq + subj + prd + drug , data=TotalData)
+lnAUC0INF<- lm(log(AUC0INF) ~ seq + subj:seq + prd + drug , data=TotalData)
 BearAnova=anova(lnAUC0INF)
 show(BearAnova)
 cat("\n")
